.. image:: https://travis-ci.org/ambitioninc/ambition-utils.png
   :target: https://travis-ci.org/ambitioninc/ambition-utils

.. image:: https://coveralls.io/repos/ambitioninc/ambition-utils/badge.png?branch=develop
    :target: https://coveralls.io/r/ambitioninc/ambition-utils?branch=develop

.. image:: https://pypip.in/v/ambition-utils/badge.png
    :target: https://crate.io/packages/ambition-utils/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/ambition-utils/badge.png
    :target: https://crate.io/packages/ambition-utils/


Requirements
------------
* Python 3.6+
* Django 1.11+
* Postgres 9.5+

Installation
------------
To install the latest release, type::

    pip install ambition-utils

To install the latest code directly from source, type::

    pip install git+git://github.com/ambitioninc/ambition-utils.git

Documentation
-------------

Note: As of version 0.5.0, this project only supports Python3.6+
If you need Python2 support, pin to `ambition-utils==0.4.0`

Full documentation is available at http://ambition-utils.readthedocs.org

License
-------
MIT License (see LICENSE)
